summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kbudgetvaluesdecl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kbudgetvaluesdecl.cpp')
-rw-r--r--kmymoney2/widgets/kbudgetvaluesdecl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/widgets/kbudgetvaluesdecl.cpp b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
index ac2e9f7..385cbfa 100644
--- a/kmymoney2/widgets/kbudgetvaluesdecl.cpp
+++ b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
@@ -28,11 +28,11 @@ inline TQString kmm_i18n(const char* msg) { return i18n(msg); }
#include <tqwhatsthis.h>
/*
* Constructs a KBudgetValuesDecl as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-KBudgetValuesDecl::KBudgetValuesDecl( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+KBudgetValuesDecl::KBudgetValuesDecl( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "KBudgetValuesDecl" );
@@ -28,11 +28,11 @@ inline TQString kmm_i18n(const char* msg) { return i18n(msg); }
#include <tqwhatsthis.h>
/*
- * Constructs a KBudgetValuesDecl as a child of 'tqparent', with the
+ * Constructs a KBudgetValuesDecl as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/